==> 0.2.3.tar.gz: elemental-on-terminal/src/main.c <==
#include "command.h"
#include "loader.h"
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define inv_file "inv.txt"
#define inv_base_file "inv_base.txt"
#define combo_file "combos.txt"

#define MAX_BUF_LENGTH 1024
#define MAX_COMBO_LENGTH 1024

void init_tables(hashmap *elements, hashmap *inv, int do_inv) {

  load_elements(elements, "../elem_data/" combo_file, 0) ||
      load_elements(elements, combo_file, 0) ||
      load_elements(elements, "bin/" combo_file, 0);

  if (!do_inv)
    return;

  load_elements(elements, "../elem_data/" inv_base_file, 1) ||
      load_elements(inv, inv_base_file, 1) ||
      load_elements(inv, "bin/" inv_base_file, 1);
}

int main(int argc, char *argv[]) {
  hashmap *elements = hashmap_create();
  hashmap *inv = hashmap_create();

  char *command = calloc(MAX_BUF_LENGTH, sizeof(char));
  char *command_re = calloc(MAX_BUF_LENGTH, sizeof(char));
  char **sort_tmp = calloc(MAX_COMBO_LENGTH, sizeof(char **));

  init_tables(elements, inv, 1);

  load_elements(inv, inv_file, 1);

  printf("Welcome to Elemental on Command Line!\n");
  while (1) {
    // todo: separate into functions

    printf("\n");
    fgets(command, MAX_BUF_LENGTH - 1, stdin);
    int slashRan = slash_command(command, inv);
    if (slashRan)
      continue;

    int combos = get_command(command, command_re, sort_tmp);

    int failed = 0;
    for (int i = 0; i < combos; i++) {
      uintptr_t result;
      hashmap_get(inv, sort_tmp[i], strlen(sort_tmp[i]), &result);
      if (result != 1) {
        printf("You don't have %s.\n", sort_tmp[i]);
        failed = 1;
        continue;
      }
    }

    if (failed)
      continue;

    uintptr_t result;
    hashmap_get(elements, command_re, strlen(command_re), &result);

    if (result == 0) {
      init_tables(elements, inv, 0);

      hashmap_get(elements, command_re, strlen(command_re), &result);
    }

    if (result == 0) {
      printf("You didn't make anything.\n");
      continue;
    }

    char *res_str = (char *)result;

    hashmap_set(inv, res_str, strlen(res_str), (uintptr_t)1, 0);
    printf("You made %s!\n", res_str);

    FILE *fptr;

    fptr = fopen(inv_file, "a");
    if (fptr == NULL)
      continue;
    fwrite(res_str, sizeof(char), strlen(res_str), fptr);
    fwrite("\n", sizeof(char), 1, fptr);
    fclose(fptr);
  }

  // free(command);
}

==> 0.3.1.tar.gz: elemental-on-terminal/src/main.c <==
#include "command.h"
#include "loader.h"
#include <ctype.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#define inv_file "inv.txt"
#define inv_base_file "inv_base.txt"
#define combo_file "combos.txt"
#define poll_file "polls.txt"
#define polls_lock_file "polls_lock.txt"

#define MAX_BUF_LENGTH 1024
#define MAX_COMBO_LENGTH 1024

void init_tables(hashmap *elements, hashmap *inv, hashmap *polls, int do_inv) {
  load_elements(elements, "../elem_data/" combo_file, 0);
  load_elements(elements, combo_file, 0) ||
      load_elements(elements, "bin/" combo_file, 0);

  load_elements(polls, "../elem_data/" poll_file, 2);

  if (!do_inv)
    return;

  load_elements(elements, "../elem_data/" inv_base_file, 1) ||
      load_elements(inv, inv_base_file, 1) ||
      load_elements(inv, "bin/" inv_base_file, 1);

  load_elements(inv, inv_file, 1);
}

int main(int argc, char *argv[]) {
  char *name;
  if (argc < 2) {
    name = "guest";
  } else {
    name = argv[1];
  }

  hashmap *elements = hashmap_create();
  hashmap *inv = hashmap_create();
  hashmap *polls = hashmap_create();

  char *command = calloc(MAX_BUF_LENGTH, sizeof(char));
  char *command_re = calloc(MAX_BUF_LENGTH, sizeof(char));
  char **sort_tmp = calloc(MAX_COMBO_LENGTH, sizeof(char **));

  int wasCombination = 0;

  init_tables(elements, inv, polls, 1);

  printf("%s, welcome to Elemental on Command Line!\n", name);
  while (1) {
    // todo: separate into functions

    printf("\n");
    fgets(command, MAX_BUF_LENGTH - 1, stdin);

    int cl = strlen(command);

    for (int i = 0; i < cl - 1; i++) {
      command[i] = tolower(command[i]);
    }

    if (wasCombination && suggest_command(command, command_re, polls, name)) {
      wasCombination = 0;
      continue;
    }
    wasCombination = 0;

    if (slash_command(command, inv))
      continue;

    int combos = get_command(command, command_re, sort_tmp);

    int failed = 0;
    for (int i = 0; i < combos; i++) {
      uintptr_t result;
      hashmap_get(inv, sort_tmp[i], strlen(sort_tmp[i]), &result);
      if (result != 1) {
        printf("You don't have %s.\n", sort_tmp[i]);
        failed = 1;
        continue;
      }
    }

    if (failed)
      continue;

    uintptr_t result;
    hashmap_get(elements, command_re, strlen(command_re), &result);

    if (result == 0) {
      init_tables(elements, inv, polls, 0);

      hashmap_get(elements, command_re, strlen(command_re), &result);
    }

    if (result == 0) {
      wasCombination = 1;
      printf("You didn't make anything; use /suggest to suggest an element.\n");
      continue;
    }

    char *res_str = (char *)result;

    hashmap_set(inv, res_str, strlen(res_str), (uintptr_t)1, 0);
    printf("You made %s!\n", res_str);

    FILE *fptr;

    fptr = fopen(inv_file, "a");
    if (fptr == NULL)
      continue;
    fwrite(res_str, sizeof(char), strlen(res_str), fptr);
    fwrite("\n", sizeof(char), 1, fptr);
    fclose(fptr);
  }

  // free(command);
}
